=== added file 'NEWS'
--- NEWS	1970-01-01 00:00:00 +0000
+++ NEWS	2009-09-24 10:26:23 +0000
@@ -0,0 +1,5 @@
+0.3
+===
+
+* Support addSkip on pythons where unittest does not support it yet.
+  (Robert Collins, lp:435400)

=== modified file 'PKG-INFO'
--- PKG-INFO	2009-09-20 17:19:22 +0000
+++ PKG-INFO	2009-09-24 10:26:23 +0000
@@ -1,6 +1,6 @@
 Metadata-Version: 1.0
 Name: junitxml
-Version: 0.2
+Version: 0.3
 Summary: PyJUnitXML, a pyunit extension to output JUnit compatible XML.
 Home-page: https://launchpad.net/pyjunitxml
 Author: Robert Collins

=== modified file 'junitxml/__init__.py'
--- junitxml/__init__.py	2009-09-20 17:19:22 +0000
+++ junitxml/__init__.py	2009-09-24 10:26:23 +0000
@@ -99,10 +99,14 @@
         self._results.append(' />\n')
 
     def addSkip(self, test, reason):
-        self._super().addSkip(test, reason)
+        try:
+            self._super().addSkip(test, reason)
+        except AttributeError:
+            # Python < 2.7|3.1
+            pass
         self._test_case_string(test)
         self._results.append('>\n')
-        self._results.append('<skip type="%s.%s">%s</skip>\n</testcase>\n'% (escape(error[0].__module__), escape(error[0].__name__), escape(reason)))
+        self._results.append('<skip>%s</skip>\n</testcase>\n'% escape(reason))
 
     def addUnexpectedSuccess(self, test):
         self._super().addUnexpectedSuccess(test, error)

=== modified file 'junitxml/tests/test_junitxml.py'
--- junitxml/tests/test_junitxml.py	2009-09-20 17:19:22 +0000
+++ junitxml/tests/test_junitxml.py	2009-09-24 10:26:23 +0000
@@ -37,6 +37,16 @@
             r'(?s)<error (.*?)>.*?</error>', r'<error \1>error</error>',
             re.sub(r'time="\d+\.\d+"', 'time="0.000"', output)))
 
+    def run_test_or_simulate(self, test, method_name, manual_method,
+        *manual_args):
+        if getattr(test, method_name, None):
+            test.run(self.result)
+        else:
+            # older python - manually execute
+            self.result.startTest(test)
+            manual_method(test, *manual_args)
+            self.result.stopTest(test)
+
     def test_startTestRun_no_output(self):
         # startTestRun doesn't output anything, because JUnit wants an up-front
         # summary.
@@ -94,27 +104,19 @@
     def test_skip_test(self):
         class Skips(unittest.TestCase):
             def test_me(self):
-                try:
-                    self.skipTest("yo")
-                except AttributeError:
-                    # Older python - degrade to a pass
-                    pass
+                self.skipTest("yo")
         self.result.startTestRun()
-        Skips("test_me").run(self.result)
+        test = Skips("test_me")
+        self.run_test_or_simulate(test, 'skipTest', self.result.addSkip, 'yo')
         self.result.stopTestRun()
         output = self.get_output()
         expected = """<testsuite errors="0" failures="0" name="" tests="0" time="0.000">
 <testcase classname="junitxml.tests.test_junitxml.Skips" name="test_me" time="0.000">
-<skip type="unittest.SkipTest">yo</skip>
+<skip>yo</skip>
 </testcase>
 </testsuite>
 """
-        expected_old = """<testsuite errors="0" failures="0" name="" tests="0" time="0.000">
-<testcase classname="junitxml.tests.test_junitxml.Skips" name="test_me" time="0.000" />
-</testsuite>
-"""
-        if output != expected_old:
-            self.assertEqual(expected, output)
+        self.assertEqual(expected, output)
 
     def test_unexpected_success_test(self):
         class Succeeds(unittest.TestCase):

=== modified file 'setup.py'
--- setup.py	2009-09-20 17:19:22 +0000
+++ setup.py	2009-09-24 10:26:23 +0000
@@ -3,7 +3,7 @@
 from distutils.core import setup
 
 setup(name="junitxml",
-      version="0.2",
+      version="0.3",
       description="PyJUnitXML, a pyunit extension to output JUnit compatible XML.",
       maintainer="Robert Collins",
       maintainer_email="robertc@robertcollins.net",

